@@ -54,7 +54,7 @@ _CMD_DPiROBOT__MOTOR_DRIVER_SET_REVERSE_DIRECTION_FLAG         = 0x43    # motor
 #
 # other constants used by this class
 #
-_DPiNETWORK_TIMEOUT_PERIOD_MS = 5
+_DPiNETWORK_TIMEOUT_PERIOD_MS = 8       # 3/10/2023 changed from 5 to 8ms
 _DPiNETWORK_BASE_ADDRESS = 0x14
 
 
@@ -99,18 +99,16 @@ class DPiRobot:
     GET_CURRENT_POSITION_UNKNOWN = 2
     GET_CURRENT_POSITION_READY = 3
 
-    #
-    # attributes local to this class
-    #
-    _slaveAddress = _DPiNETWORK_BASE_ADDRESS
-    _commErrorCount = 0
-
 
     #
     # constructor for the DPiRobot class
     #
     def __init__(self):
-        pass
+        #
+        # attribute variables local to one instance of this class
+        #
+        self._slaveAddress = _DPiNETWORK_BASE_ADDRESS
+        self._commErrorCount = 0
 
 
     # ---------------------------------------------------------------------------------
